@@ -39,7 +39,7 @@
 # THE SOFTWARE.
 #===============================================================================
 
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 __project__ = "https://github.com/zTrix/zio"
 
 import struct, socket, os, sys, subprocess, threading, pty, time, re, select, termios, resource, tty, errno, signal, fcntl, gc, platform, datetime
@@ -54,7 +54,7 @@ except:
     def colored(text, color=None, on_color=None, attrs=None):
         return text
 
-__all__ = ['stdout', 'log', 'l8', 'b8', 'l16', 'b16', 'l32', 'b32', 'l64', 'b64', 'zio', 'EOF', 'TIMEOUT', 'SOCKET', 'PROCESS', 'REPR', 'EVAL', 'HEX', 'UNHEX', 'BIN', 'UNBIN', 'RAW', 'NONE', 'COLORED', 'PIPE', 'TTY', 'TTY_RAW']
+__all__ = ['stdout', 'log', 'l8', 'b8', 'l16', 'b16', 'l32', 'b32', 'l64', 'b64', 'zio', 'EOF', 'TIMEOUT', 'SOCKET', 'PROCESS', 'REPR', 'EVAL', 'HEX', 'UNHEX', 'BIN', 'UNBIN', 'RAW', 'NONE', 'COLORED', 'PIPE', 'TTY', 'TTY_RAW', 'cmdline']
 
 def stdout(s, color = None, on_color = None, attrs = None):
     if not color:
@@ -1694,7 +1694,7 @@ def usage():
     print """
 usage:
 
-    $ zio.py [options] cmdline | host port
+    $ zio [options] cmdline | host port
 
 options:
 
@@ -1711,22 +1711,22 @@ options:
 
 examples:
 
-    $ zio.py -h
+    $ zio -h
         you are reading this help message
 
-    $ zio.py [-t seconds] [-i [tty|pipe]] [-o [tty|pipe]] "cmdline -x opts and args"
+    $ zio [-t seconds] [-i [tty|pipe]] [-o [tty|pipe]] "cmdline -x opts and args"
         spawning process and interact with it
 
-    $ zio.py [-t seconds] host port
+    $ zio [-t seconds] host port
         zio becomes a netcat
 
-    $ ./zio.py tty
-    $ ./zio.py cat
-    $ ./zio.py vim
-    $ ./zio.py ssh -p 22 root@127.0.0.1
-    $ ./zio.py xxd
-    $ ./zio.py 127.1 22                 # WOW! you can talk with sshd by hand!
-    $ ./zio.py -i pipe ssh root@127.1   # you must be crazy to do this!
+    $ zio tty
+    $ zio cat
+    $ zio vim
+    $ zio ssh -p 22 root@127.0.0.1
+    $ zio xxd
+    $ zio 127.1 22                 # WOW! you can talk with sshd by hand!
+    $ zio -i pipe ssh root@127.1   # you must be crazy to do this!
 """
 
 def cmdline(argv):
@@ -1822,8 +1822,7 @@ def cmdline(argv):
         io.write(ahead)
     io.interact(input_filter = decode, raw_rw = False)
 
-if __name__ == '__main__':
-
+def main():
     if len(sys.argv) >= 2:
         test = sys.argv[1]
     else:
@@ -1832,4 +1831,7 @@ if __name__ == '__main__':
 
     cmdline(sys.argv[1:])
 
+if __name__ == '__main__':
+    main()
+
 # vi:set et ts=4 sw=4 ft=python :
